@@ -970,11 +970,31 @@ class fit_files(object):
             fitxx = fitx
             xlabel = self.bfit.xlabel_dict[self.mode]
     
-        self.plt.plot(figstyle,draw_id,fitxx,fn(fitx,*fit_par),zorder=10,
+        # get fity
+        fity = fn(fitx,*fit_par)
+    
+        # account for normalized draw modes
+        draw_mode = self.bfit.asym_dict[self.bfit.fetch_files.asym_type.get()]
+        if draw_mode == 'cn1':
+            draw_mode += 'f'
+            fity /= data.fitpar['res']['baseline']
+        
+        elif draw_mode == 'cn2':
+            draw_mode += 'f'
+            if 'amp' in data.fitpar['res'].keys():
+                fity /= data.fitpar['res']['amp']
+            else:
+                fity /= fn(t[0],*par)
+        
+        elif draw_mode == 'cs':
+            draw_mode += 'f'
+            fity -= data.fitpar['res']['baseline']
+                
+        self.plt.plot(figstyle,draw_id,fitxx,fity,zorder=10,
                       unique=unique,**drawargs)
         
         # plot elements
-        self.plt.ylabel(figstyle,'Asymmetry')
+        self.plt.ylabel(figstyle,self.bfit.ylabel_dict.get(draw_mode,'Asymmetry'))
         self.plt.xlabel(figstyle,xlabel)
         
         # show
@@ -1071,7 +1091,10 @@ class fit_files(object):
             xerrs = None
             ax.tick_params(axis='x', which='major', labelsize='x-small')
         else:
-            ax.get_xaxis().get_major_formatter().set_useOffset(False)
+            try:
+                ax.get_xaxis().get_major_formatter().set_useOffset(False)
+            except AttributeError:
+                pass
         
         if ydraw in ('Start Time',):    
             ax.yaxis.set_major_formatter(mdates.DateFormatter('%y/%m/%d (%H:%M)'))
@@ -1079,7 +1102,10 @@ class fit_files(object):
             yerrs = None
             ax.tick_params(axis='y', which='major', labelsize='x-small')
         else:
-            ax.get_yaxis().get_major_formatter().set_useOffset(False)
+            try:
+                ax.get_yaxis().get_major_formatter().set_useOffset(False)
+            except AttributeError:
+                pass
             
         # draw
         f = self.plt.errorbar(figstyle,draw_id,xvals,yvals,xerr=xerrs,yerr=yerrs,
